@@ -1,5 +1,4 @@
 import tensorflow as tf
-import tensorflow_addons as tfa
 import numpy as np
 from typing import Text, List, Dict, Any, Union, Optional, Tuple, Callable
 
@@ -1026,7 +1025,7 @@ class RasaSequenceLayer(RasaCustomLayer):
             outputs, attention_weights = self._tf_layers[self.TRANSFORMER](
                 seq_sent_features_masked, mask_padding, training
             )
-            outputs = tfa.activations.gelu(outputs)
+            outputs = tf.nn.gelu(outputs)
         else:
             # tf.zeros((0,)) is an alternative to None
             outputs, attention_weights = seq_sent_features_masked, tf.zeros((0,))
